Draw a list of sprites to the specified view.

Use [UniformSetValueList] and [UniformSetTextureList] to pass uniform values to the shader program.

*Note:* This function prepares the sprite on the CPU before submitting them all to the GPU as a single draw call.
